@@ -4,12 +4,16 @@ import threading
 import ssl
 import datetime
 import requests
+import logging
+
 from collections import OrderedDict
 from threading import Event
 from paho.mqtt.client import Client  as ClientMQTT
 from paho.mqtt import publish as MQTTPublish
 from paho.mqtt import subscribe as MQTTSubscribe
 
+_LOGGER = logging.getLogger(__name__)
+
 def str_to_bool_or_cert(s):
     if s == 'True' or s == True:
         return True
@@ -242,7 +246,6 @@ class EcoVacsIOTMQ(ClientMQTT):
             elif 'getwater' in eventname:
                 jsonstring['event'] = "water_info"
             else:
-                _LOGGER.warning('UKNOWN Status:' + eventname)
                 return
         else:
             if jsonstring['body']['msg'] == 'fail':
